@@ -1,16 +1,16 @@
 package Data::Sah::Coerce::perl::To_obj::From_str::math_complex;
 
-# AUTHOR
-our $DATE = '2021-07-19'; # DATE
-our $DIST = 'Sah-Schemas-Math'; # DIST
-our $VERSION = '0.002'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
 
 use Regexp::Pattern::Float;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-12-11'; # DATE
+our $DIST = 'Sah-Schemas-Math'; # DIST
+our $VERSION = '0.003'; # VERSION
+
 my $re_float_decimal =
     $Regexp::Pattern::Float::RE{float_decimal}{pat};
 my $re_float_decimal_or_exp =
@@ -19,7 +19,7 @@ my $re_float_decimal_or_exp =
 sub meta {
     +{
         v => 4,
-        summary => 'Coerce complex number from string in the form of "a + bi"',
+        summary => 'Coerce complex number from string in the form of "<a> + <b>i"',
         prio => 50,
     };
 }
@@ -56,7 +56,7 @@ Data::Sah::Coerce::perl::To_obj::From_str::math_complex
 
 =head1 VERSION
 
-This document describes version 0.002 of Data::Sah::Coerce::perl::To_obj::From_str::math_complex (from Perl distribution Sah-Schemas-Math), released on 2021-07-19.
+This document describes version 0.003 of Data::Sah::Coerce::perl::To_obj::From_str::math_complex (from Perl distribution Sah-Schemas-Math), released on 2021-12-11.
 
 =for Pod::Coverage ^(meta|coerce)$
 
@@ -68,6 +68,34 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Math>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2021, 2020 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Math>
@@ -76,15 +104,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
